@@ -48,6 +48,7 @@ set_locale_for_clients() {
 } # end of set_locale_for_clients
 #
 config_network(){
+  echo "Detecting the network status..."
   eth_port_no="$(get-nic-devs | wc -l)"
   configured_ip_no="$(get-all-nic-ip -i | wc -w)"
   while [ "$configured_ip_no" -lt "$eth_port_no" ]; do
@@ -83,8 +84,8 @@ config_network(){
   if [ "$IP_no" -eq 0 ]; then
     [ "$BOOTUP" = "color" ] && $SETCOLOR_FAILURE
     echo $msg_no_ip_address_is_configured
-    echo "$msg_program_stop"
     [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
+    echo "$msg_program_stop"
     exit 1
   elif [ "$IP_no" -eq 1 ]; then
     [ "$BOOTUP" = "color" ] && $SETCOLOR_WARNING
@@ -133,6 +134,15 @@ fi
 
 switch=$1
 
+#
+if ! is_boot_from_live; then
+  [ "$BOOTUP" = "color" ] && $SETCOLOR_FAILURE
+  echo "This command $0 is used in DRBL Live environment only!"
+  [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
+  echo "$msg_program_stop"
+  exit 1
+fi
+
 case "$switch" in
    "start"|"restart")
      # config network first:
@@ -146,7 +156,7 @@ case "$switch" in
      read
 
      # load $client_no_per_NIC and $autologin_passwd_opt for later use
-     . /opt/drbl/setup/files/ocs/live-hook/ocs-live.conf
+     . $drbl_setup_path/files/ocs/live-hook/ocs-live.conf
 
      # run drblpush again so that the network interface can be updated. Maybe there is new ethx.
      yes "" | drblpush -i -r 1 -z 1 --not-add-start-drbl-srvi -p $client_no_per_NIC
@@ -155,7 +165,6 @@ case "$switch" in
      # modify dhcpd.conf, provide IP address to PXE/Etherboot/DRBL client only
      echo "Modifying dhcpd.conf, now only PXE/Etherboot/DRBL client can lease IP address..."
      perl -pi -e 's/^([[:space:]]*)#[[:space:]]*(allow members of "DRBL-Client";)/$1 $2/g' /etc/dhcp3/dhcpd.conf
-     /etc/init.d/dhcp3-server restart
 
      echo "$msg_delimiter_star_line"
      echo "Enable auto login for drbl clients..."
@@ -194,6 +203,10 @@ case "$switch" in
      # set locales for clients.
      set_locale_for_clients
 
+     #
+     echo "Start all DRBL related services by running 'drbl-all-service start'..."
+     drbl-all-service start
+
      #
      echo "$msg_delimiter_star_line"
      echo "$msg_done!"
@@ -201,12 +214,24 @@ case "$switch" in
      echo "$msg_all_set_you_can_turn_on_clients"
      [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
      echo -n $msg_press_enter_to_continue
-     read
+     # This is a weird problem about tftpd-hpa when it is restared in 'drbl-all-service start' in the above. It's:
+     # -------
+     # /etc/init.d/tftpd-hpa restart
+     # echo -n "press key... "
+     # read
+     # -------
+     # and we always get such an error when running it:
+     # -------
+     # Restarting HPA's tftpd: in.tftpd.
+     # press key... ./td: line 4: read: read error: 0: Resource temporarily unavailable
+     # -------
+     # Therefore we use < /dev/stdin to avoid tihs.
+     read dummy_var < /dev/stdin
      ;;
    "stop")
      # block all the clients.
      mv -f /etc/hosts.allow /etc/hosts.allow.orig2
-     echo "Disabled by drbl-live.sh" > /etc/hosts.allow
+     echo "# Disabled by drbl-live.sh" > /etc/hosts.allow
 
      # stop and remove all services
      echo "Stop DRBL service.."
